@@ -43,7 +43,7 @@ COMPLETE_STATUSES = (
 
 def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_type=clusters.CLUSTER_TYPE_PERSISTENT,
                          git_ref='master', parameters=None, notify_on_job_finish=True, is_control_script=False,
-                         pig_version=None, use_spot_instances=False):
+                         pig_version=None, use_spot_instances=False, pipeline_job_id=None):
     """
     Post a new job to a new cluster.
 
@@ -80,6 +80,9 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
     :type use_spot_instances: bool
     :param use_spot_instances: whether to launch a cluster using spot instances. Default: false.
 
+    :type pipeline_job_id: string
+    :param pipeline_job_id: Luigi pipeline that launched this job, if applicable. Default: None.
+
     :raises: requests.exception.HTTPError: if a 40x or 50x error occurs
 
     :rtype: str:
@@ -91,7 +94,8 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
             'cluster_type': cluster_type,
             'parameters': parameters or {},
             'notify_on_job_finish': notify_on_job_finish,
-            'use_spot_instances': use_spot_instances
+            'use_spot_instances': use_spot_instances,
+            'pipeline_job_id': pipeline_job_id
     }
 
     if is_control_script:
@@ -156,7 +160,7 @@ def post_web_job_new_cluster(api, script_name, cluster_size, cluster_type=cluste
 
 def post_job_existing_cluster(api, project_name, script_name, cluster_id, cluster_type=clusters.CLUSTER_TYPE_PERSISTENT,
                               git_ref='master', parameters=None, notify_on_job_finish=True, is_control_script=False,
-                              pig_version=None):
+                              pig_version=None, pipeline_job_id=None):
     """
     Post a new job to an existing cluster.
 
@@ -187,6 +191,9 @@ def post_job_existing_cluster(api, project_name, script_name, cluster_id, cluste
     :type pig_version: string
     :param pig_version: Major version of pig to run.  If null, uses the Mortar platform default (currently 0.9).
 
+    :type pipeline_job_id: string
+    :param pipeline_job_id: Luigi pipeline that launched this job, if applicable. Default: None.
+
     :raises: requests.exception.HTTPError: if a 40x or 50x error occurs
 
     :rtype: str:
@@ -196,7 +203,8 @@ def post_job_existing_cluster(api, project_name, script_name, cluster_id, cluste
             'git_ref': git_ref,
             'cluster_id': cluster_id,
             'parameters': parameters or {},
-            'notify_on_job_finish': notify_on_job_finish
+            'notify_on_job_finish': notify_on_job_finish,
+            'pipeline_job_id': pipeline_job_id
     }
 
     if is_control_script:
